## 25.11.29.20251201 (2025-12-01)

[stubsabot] Bump flake8-bugbear to 25.11.29 ([#15096](https://github.com/python/typeshed/pull/15096))

Release: https://pypi.org/pypi/flake8-bugbear/25.11.29
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/25.10.21...25.11.29

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/eval_files/b043.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 97.
 - Total lines of Python code deleted: 3.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 25.10.21.20251024 (2025-10-24)

[flake8-bugbear] Update to 25.10.21 ([#14912](https://github.com/python/typeshed/pull/14912))

## 24.12.12.20251008 (2025-10-08)

Stubtest: Ignore attrs-generated props ([#14845](https://github.com/python/typeshed/pull/14845))

## 24.12.12.20250416 (2025-04-16)

Improve `flake8-bugbear` (#13829)

## 24.12.12.20241214 (2024-12-14)

[stubsabot] Bump flake8-bugbear to 24.12.12 (#13235)

Release: https://pypi.org/pypi/flake8-bugbear/24.12.12
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/24.10.31...24.12.12

Stubsabot analysis of the diff between the two releases:
 - 9 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 595.
 - Total lines of Python code deleted: 43.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 24.10.31.20241103 (2024-11-03)

[stubsabot] Bump flake8-bugbear to 24.10.31 (#12938)

Release: https://pypi.org/pypi/flake8-bugbear/24.10.31
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/24.8.19...24.10.31

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/b041.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 103.
 - Total lines of Python code deleted: 9.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 24.8.19.20240822 (2024-08-22)

[stubsabot] Bump flake8-bugbear to 24.8.19 (#12567)

## 24.4.26.20240428 (2024-04-28)

[stubsabot] Bump flake8-bugbear to 24.4.26 (#11836)

Release: https://pypi.org/pypi/flake8-bugbear/24.4.26
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/24.4.21...24.4.26

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 74.
 - Total lines of Python code deleted: 4.

## 24.4.21.20240423 (2024-04-23)

[stubsabot] Bump flake8-bugbear to 24.4.21 (#11806)

Release: https://pypi.org/pypi/flake8-bugbear/24.4.21
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/24.2.6...24.4.21

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 192.
 - Total lines of Python code deleted: 88.

## 24.2.6.20240209 (2024-02-09)

[stubsabot] Bump flake8-bugbear to 24.2.6 (#11379)

## 24.1.17.20240201 (2024-02-01)

[stubsabot] Bump flake8-bugbear to 24.1.17 (#11278)

Release: https://pypi.org/pypi/flake8-bugbear/24.1.17
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.12.2...24.1.17

Stubsabot analysis of the diff between the two releases:
 - 3 public Python files have been added: `tests/b036.py`, `tests/b037.py`, `tests/b038.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 410.
 - Total lines of Python code deleted: 35.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 23.12.2.0 (2023-12-03)

[stubsabot] Bump flake8-bugbear to 23.12.2 (#11097)

Release: https://pypi.org/pypi/flake8-bugbear/23.12.2
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.11.28...23.12.2

Stubsabot analysis of the diff between the two releases:
 - 2 public Python files have been added: `scripts/flake8_py_version_check.py`, `tests/b018_nested.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 180.
 - Total lines of Python code deleted: 29.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 23.11.28.0 (2023-11-30)

[stubsabot] Bump flake8-bugbear to 23.11.28 (#11088)

Release: https://pypi.org/pypi/flake8-bugbear/23.11.28
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.11.26...23.11.28

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 50.
 - Total lines of Python code deleted: 3.

## 23.11.26.0 (2023-11-28)

[stubsabot] Bump flake8-bugbear to 23.11.26 (#11075)

Release: https://pypi.org/pypi/flake8-bugbear/23.11.26
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.9.16...23.11.26

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/b035.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 175.
 - Total lines of Python code deleted: 61.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 23.9.16.0 (2023-09-17)

[stubsabot] Bump flake8-bugbear to 23.9.16 (#10720)

Release: https://pypi.org/pypi/flake8-bugbear/23.9.16
Homepage: https://github.com/PyCQA/flake8-bugbear
Repository: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.7.10...23.9.16

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/b902_extended.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 352.
 - Total lines of Python code deleted: 286.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 23.7.10.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 23.7.10.0 (2023-07-11)

[stubsabot] Bump flake8-bugbear to 23.7.10 (#10434)

Release: https://pypi.org/pypi/flake8-bugbear/23.7.10
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.6.5...23.7.10

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/b034.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 230.
 - Total lines of Python code deleted: 91.

## 23.6.5.0 (2023-06-06)

[stubsabot] Bump flake8-bugbear to 23.6.5 (#10265)

Release: https://pypi.org/pypi/flake8-bugbear/23.6.5
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.5.9...23.6.5

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 31.
 - Total lines of Python code deleted: 18.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 23.5.9.1 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 23.5.9.0 (2023-05-10)

[stubsabot] Bump flake8-bugbear to 23.5.9 (#10165)

Release: https://pypi.org/pypi/flake8-bugbear/23.5.9
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.3.23...23.5.9

Stubsabot analysis of the diff between the two releases:
 - 2 public Python files have been added: `tests/b033.py`, `tests/b908.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 190.
 - Total lines of Python code deleted: 26.

## 23.3.23.0 (2023-03-24)

[stubsabot] Bump flake8-bugbear to 23.3.23 (#9934)

Release: https://pypi.org/pypi/flake8-bugbear/23.3.23
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.3.12...23.3.23

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 48.
 - Total lines of Python code deleted: 26.

## 23.3.12.0 (2023-03-13)

[stubsabot] Bump flake8-bugbear to 23.3.12 (#9872)

Release: https://pypi.org/pypi/flake8-bugbear/23.3.12
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.2.13...23.3.12

Co-authored-by: stubsabot <>

## 23.2.13.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 23.2.13.0 (2023-02-14)

[stubsabot] Bump flake8-bugbear to 23.2.13 (#9729)

## 23.1.20.0 (2023-01-21)

[stubsabot] Bump flake8-bugbear to 23.1.20 (#9576)

Release: https://pypi.org/pypi/flake8-bugbear/23.1.20
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.1.17...23.1.20

## 23.1.17.0 (2023-01-19)

Bump flake8-bugbear to 23.1.17 (#9569)

Release: https://pypi.org/pypi/flake8-bugbear/23.1.17
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/23.1.14...23.1.17

## 23.1.14.0 (2023-01-15)

[stubsabot] Bump flake8-bugbear to 23.1.14 (#9541)

Release: https://pypi.org/pypi/flake8-bugbear/23.1.14
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/22.12.6...23.1.14

## 22.12.6.0 (2022-12-07)

[stubsabot] Bump flake8-bugbear to 22.12.6 (#9340)

Release: https://pypi.org/pypi/flake8-bugbear/22.12.6
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/22.10.27...22.12.6

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/b905_py310.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 55.
 - Total lines of Python code deleted: 9.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 22.10.27.0 (2022-10-27)

[stubsabot] Bump flake8-bugbear to 22.10.27 (#8992)

Release: https://pypi.org/pypi/flake8-bugbear/22.10.27
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/22.10.25...22.10.27

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 193.
 - Total lines of Python code deleted: 28.

## 22.10.25.0 (2022-10-25)

[stubsabot] Bump flake8-bugbear to 22.10.25 (#8980)

Release: https://pypi.org/pypi/flake8-bugbear/22.10.25
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/22.9.23...22.10.25

Stubsabot analysis of the diff between the two releases:
 - 1 public Python file has been added: `tests/b027.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `bugbear.py`.
 - Total lines of Python code added: 194.
 - Total lines of Python code deleted: 35.

## 22.9.23.1 (2022-10-15)

Use `Incomplete` instead of `Any` in `__getattr__` (#8903)

## 22.9.23.0 (2022-09-30)

[stubsabot] Bump flake8-bugbear to 22.9.23 (#8812)

Release: https://pypi.org/pypi/flake8-bugbear/22.9.23
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/22.9.11...22.9.23

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

## 22.9.11.0 (2022-09-16)

[stubsabot] Bump flake8-bugbear to 22.9.11 (#8747)

Release: https://pypi.org/project/flake8-bugbear/22.9.11/
Homepage: https://github.com/PyCQA/flake8-bugbear
Changelog: https://github.com/PyCQA/flake8-bugbear#change-log
Diff: https://github.com/PyCQA/flake8-bugbear/compare/22.8.23...22.9.11

## 22.8.23.0 (2022-08-26)

[stubsabot] Bump flake8-bugbear to 22.8.23 (#8622)

## 22.7.1.0 (2022-07-01)

[stubsabot] Bump flake8-bugbear to 22.7.1 (#8220)

## 22.6.22.0 (2022-06-25)

[stubsabot] Bump flake8-bugbear to 22.6.22 (#8151)

Co-authored-by: hauntsaninja <>

## 22.4.25.0 (2022-06-21)

[stubsabot] Bump flake8-bugbear to 22.4.25 (#8112)

Co-authored-by: hauntsaninja <>

## 21.11.29.2 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 21.11.29.0 (2021-12-08)

Add stubs for flake8-bugbear (#6543)

